## Immediate TODO

- [x] more job details when printing job stuff, especially when removing or killing
- [x] setup
- [ ] dependent jobs (a after b is done)
- [ ] better secrets management
- [ ] git branch mode
- [ ] multi node and auth
- [ ] documentation
- [ ] job execution isolation
